@@ -14,7 +14,8 @@
 # ==============================================================================
 """Base interfaces and datatypes."""
 
-from typing import Any, Callable, NamedTuple, Optional, Protocol, runtime_checkable, Sequence, Union
+from collections.abc import Callable
+from typing import Any, NamedTuple, Optional, Protocol, Sequence, Union, runtime_checkable
 
 import chex
 import jax
@@ -22,7 +23,8 @@ import jax.numpy as jnp
 
 NO_PARAMS_MSG = (
     'You are using a transformation that requires the current value of '
-    'parameters, but you are not passing `params` when calling `update`.')
+    'parameters, but you are not passing `params` when calling `update`.'
+)
 
 PyTree = Any
 Shape = Sequence[int]
@@ -40,9 +42,7 @@ ScalarOrSchedule = Union[float, jax.Array, Schedule]
 class StatefulSchedule(Protocol):
   """Base interface for stateful schedules."""
 
-  def init(
-      self
-  ) -> ScheduleState:
+  def init(self) -> ScheduleState:
     """Initialize the state of the stateful schedule."""
 
   def update(
@@ -84,7 +84,7 @@ class TransformUpdateFn(Protocol):
 
   The `update` step takes a tree of candidate parameter `updates` (e.g. their
   gradient with respect to some loss), an arbitrary structured `state`, and the
-  current `params` of the model being optimised. The `params` argument is
+  current `params` of the model being optimized. The `params` argument is
   optional, it must however be provided when using transformations that require
   access to the current values of the parameters.
 
@@ -93,11 +93,8 @@ class TransformUpdateFn(Protocol):
   """
 
   def __call__(
-      self,
-      updates: Updates,
-      state: OptState,
-      params: Optional[Params] = None
-    ) -> tuple[Updates, OptState]:
+      self, updates: Updates, state: OptState, params: Optional[Params] = None
+  ) -> tuple[Updates, OptState]:
     """The `update` function.
 
     Args:
@@ -144,35 +141,39 @@ class TransformUpdateExtraArgsFn(Protocol):
         arguments, ignoring those that are not needed for the current
         transformation. Transformations that require specific extra args should
         specify these using keyword-only arguments.
+
     Returns:
       Transformed updates, and an updated value for the state.
     """
 
 
 class GradientTransformation(NamedTuple):
+  # pylint: disable=line-too-long
   """A pair of pure functions implementing a gradient transformation.
 
-  Optax optimizers are all implemented as _gradient transformations_.
+  Optax optimizers are all implemented as *gradient transformations*.
   A gradient transformation is defined to be a pair of pure functions, which
   are combined together in a `NamedTuple` so that they can be referred to by
   name.
 
   Note that an extended API is provided for users wishing to build optimizers
   that take additional arguments during the update step. For more details,
-  see ``GradientTransoformationExtraArgs``.
+  see :func:`optax.GradientTransoformationExtraArgs`.
 
   Since gradient transformations do not contain any internal state, all stateful
   optimizer properties (such as the current step count when using optimizer
-  scheduels, or  momemtum values) are passed through optax gradient
-  transformations by using the optimizer _state_ pytree. Each time a gradient
+  schedules or  momentum values) are passed through optax gradient
+  transformations by using the optimizer *state* pytree. Each time a gradient
   transformation is applied, a new state is computed and returned, ready to be
   passed to the next call to the gradient transformation.
 
   Since gradient transformations are pure, idempotent functions, the only way
-  to change the behaviour of a gradient transformation between steps, is to
+  to change the behavior of a gradient transformation between steps, is to
   change the values in the optimizer state. To see an example of mutating the
-  optimizer state in order to control the behaviour of an optax gradient
-  transformation, see the meta-learning example in the optax documentation.
+  optimizer state in order to control the behavior of an optax gradient
+  transformation see the `meta-learning example
+  <https://optax.readthedocs.io/en/latest/_collections/examples/meta_learning.html>`_
+  in the optax documentation.
 
   Attributes:
     init: A pure function which, when called with an example instance of the
@@ -184,6 +185,7 @@ class GradientTransformation(NamedTuple):
       function), and optionally the current params. The update function then
       returns the computed gradient updates, and a new optimizer state.
   """
+  # pylint: disable=line-too-long
   init: TransformInitFn
   update: TransformUpdateFn
 
@@ -205,6 +207,7 @@ class GradientTransformationExtraArgs(GradientTransformation):
     update: Overrides the type signature of the update in the base type to
       accept extra arguments.
   """
+
   update: TransformUpdateExtraArgsFn
 
 
@@ -228,7 +231,7 @@ def identity() -> GradientTransformation:
   to be left unchanged when the updates are applied to them.
 
   Returns:
-    A `GradientTransformation` object.
+    A :class:`optax.GradientTransformation` object.
   """
 
   def update_fn(updates, state, params=None):
@@ -255,12 +258,12 @@ def set_to_zero() -> GradientTransformation:
   parameters, unnecessary computations will in general be dropped.
 
   Returns:
-    A `GradientTransformation` object.
+    A :class:`optax.GradientTransformation` object.
   """
 
   def update_fn(updates, state, params=None):
     del params  # Unused by the zero transform.
-    return jax.tree_util.tree_map(jnp.zeros_like, updates), state
+    return jax.tree.map(jnp.zeros_like, updates), state
 
   return GradientTransformation(init_empty_state, update_fn)
 
@@ -274,11 +277,11 @@ def stateless(
   does not require saved state between iterations.
 
   Args:
-    f: Update function that takes in updates (e.g. gradients) and parameters
-      and returns updates. The parameters may be `None`.
+    f: Update function that takes in updates (e.g. gradients) and parameters and
+      returns updates. The parameters may be `None`.
 
   Returns:
-    An `optax.GradientTransformation`.
+    A :class:`optax.GradientTransformation`.
   """
 
   def update_fn(updates, state, params=None):
@@ -295,7 +298,7 @@ def stateless_with_tree_map(
 
   This wrapper eliminates the boilerplate needed to create a transformation that
   does not require saved state between iterations, just like optax.stateless.
-  In addition, this function will apply the tree_map over update/params for you.
+  In addition, this function will apply the tree map over update/params for you.
 
   Args:
     f: Update function that takes in an update array (e.g. gradients) and
@@ -303,16 +306,16 @@ def stateless_with_tree_map(
       `None`.
 
   Returns:
-    An `optax.GradientTransformation`.
+    A :class:`optax.GradientTransformation`.
   """
 
   def update_fn(updates, state, params=None):
     del state
     if params is not None:
-      return jax.tree_util.tree_map(f, updates, params), EmptyState()
+      return jax.tree.map(f, updates, params), EmptyState()
     else:
       f_ = lambda u: f(u, None)
-      return jax.tree_util.tree_map(f_, updates), EmptyState()
+      return jax.tree.map(f_, updates), EmptyState()
 
   return GradientTransformation(init_empty_state, update_fn)
 
