@@ -14,8 +14,9 @@
 # ==============================================================================
 """Line-searches."""
 
+from collections.abc import Callable
 import functools
-from typing import Any, Callable, NamedTuple, Optional, Union
+from typing import Any, NamedTuple, Optional, Union
 
 import chex
 import jax
@@ -26,6 +27,20 @@ from optax._src import utils
 import optax.tree_utils as otu
 
 
+class BacktrackingLinesearchInfo(NamedTuple):
+  """Information about the backtracking linesearch step, for debugging.
+
+  Attributes:
+    num_linesearch_steps: number of linesearch steps.
+    decrease_error: error of the decrease criterion at the end of the
+      linesearch. A positive value indicates that
+      the linesearch failed to find a stepsize that ensures a sufficient
+      decrease. A null value indicates it succeeded in finding such a stepsize.
+  """
+  num_linesearch_steps: int
+  decrease_error: Union[float, chex.Numeric]
+
+
 class ScaleByBacktrackingLinesearchState(NamedTuple):
   """State for :func:`optax.scale_by_backtracking_linesearch`.
 
@@ -38,20 +53,22 @@ class ScaleByBacktrackingLinesearchState(NamedTuple):
       line-search if the line-search is instantiated with store_grad = True.
       Otherwise it is None. Can be reused using
       :func:`optax.value_and_grad_from_state`.
+    info: information about the backtracking linesearch step, for debugging.
   """
 
   learning_rate: Union[float, jax.Array]
   value: Union[float, jax.Array]
-  grad: Optional[base.Updates] = None
+  grad: Optional[base.Updates]
+  info: BacktrackingLinesearchInfo
 
 
-class BacktrackingSearchState(NamedTuple):
+class BacktrackingLineSearchState(NamedTuple):
   """State during the inner loop of a backtracking line-search."""
 
   learning_rate: Union[float, jax.Array]
   new_value: Union[float, jax.Array]
   new_grad: base.Updates
-  accepted: bool
+  decrease_error: chex.Numeric
   iter_num: Union[int, jax.Array]
 
 
@@ -64,6 +81,7 @@ def scale_by_backtracking_linesearch(
     atol: float = 0.0,
     rtol: float = 0.0,
     store_grad: bool = False,
+    verbose: bool = False,
 ) -> base.GradientTransformationExtraArgs:
   r"""Backtracking line-search ensuring sufficient decrease (Armijo criterion).
 
@@ -89,29 +107,37 @@ def scale_by_backtracking_linesearch(
   The algorithm starts with a given guess of a learning rate and decrease it
   by ``decrease_factor`` until the criterion above is met.
 
-  .. warning::
-    The sufficient decrease criterion might be impossible to satisfy for some
-    update directions. To guarantee a non-trivial solution for the sufficient
-    decrease criterion, a descent direction for updates (:math:`u`) is required.
-    An update (:math:`u`) is considered a descent direction if the derivative of
-    :math:`f(w + \eta u)` at :math:`\eta = 0`
-    (i.e.,  :math:`\langle u, \nabla f(w)\rangle`) is negative.  This condition
-    is automatically satisfied when using :func:`optax.sgd` (without momentum),
-    but may not hold true for other optimizers like :func:`optax.adam`.
+  Args:
+    max_backtracking_steps: maximum number of iterations for the line-search.
+    slope_rtol: relative tolerance w.r.t. to the slope. The sufficient decrease
+      must be slope_rtol * lr * <grad, updates>, see formula above.
+    decrease_factor: decreasing factor to reduce learning rate.
+    increase_factor: increasing factor to increase learning rate guess. Setting
+      it to 1. amounts to keep the current guess, setting it to ``math.inf``
+      amounts to start with ``max_learning_rate`` at each round.
+    max_learning_rate: maximum learning rate (learning rate guess clipped to
+      this).
+    atol: absolute tolerance at which the criterion needs to be satisfied.
+    rtol: relative tolerance at which the criterion needs to be satisfied.
+    store_grad: whether to compute and store the gradient at the end of the
+      linesearch. Since the function is called to compute the value to accept
+      the learning rate, we can also access the gradient along the way. By doing
+      that, we can directly reuse the value and the gradient computed at the end
+      of the linesearch for the next iteration using
+      :func:`optax.value_and_grad_from_state`. See the example above.
+    verbose: whether to print debugging information.
 
+  Returns:
+    A :class:`GradientTransformationExtraArgs`, where the ``update`` function
+    takes the following additional keyword arguments:
 
-    More generally, when chained with other transforms as
-    ``optax.chain(opt_1, ..., opt_k,
-    scale_by_backtraking_linesearch(max_backtracking_steps=...),
-    opt_kplusone, ..., opt_n)``, the updates returned by chaining
-    ``opt_1, ..., opt_k`` must be a descent direction. However, any transform
-    after the backtracking line-search doesn't necessarily need to satisfy the
-    descent direction property (one could for example use momentum).
-
-  .. seealso:: :func:`optax.value_and_grad_from_state` to make this method
-    more efficient for non-stochastic objectives.
-
-  .. versionadded:: 0.2.0
+    * ``value``: value of the function at the current params.
+    * ``grad``: gradient of the function at the current params.
+    * ``value_fn``: function returning the value of the function we seek to
+      optimize.
+    * ``**extra_args``: additional keyword arguments, if the function needs
+      additional arguments such as input data, they should be put there (
+      see example in this docstring).
 
   Examples:
 
@@ -187,7 +213,6 @@ def scale_by_backtracking_linesearch(
       Objective function: 2.35E-01
       Objective function: 8.47E-02
 
-
   References:
     Vaswani et al., `Painless Stochastic Gradient
     <https://arxiv.org/abs/1905.09997>`_, 2019
@@ -195,36 +220,30 @@ def scale_by_backtracking_linesearch(
     Nocedal & Wright, `Numerical Optimization
     <https://doi.org/10.1007/978-0-387-40065-5>`_, 1999
 
-  Args:
-    max_backtracking_steps: maximum number of iterations for the line-search.
-    slope_rtol: relative tolerance w.r.t. to the slope. The sufficient decrease
-      must be slope_rtol * lr * <grad, updates>, see formula above.
-    decrease_factor: decreasing factor to reduce learning rate.
-    increase_factor: increasing factor to increase learning rate guess. Setting
-      it to 1. amounts to keep the current guess, setting it to ``math.inf``
-      amounts to start with ``max_learning_rate`` at each round.
-    max_learning_rate: maximum learning rate (learning rate guess clipped to
-      this).
-    atol: absolute tolerance at which the criterion needs to be satisfied.
-    rtol: relative tolerance at which the criterion needs to be satisfied.
-    store_grad: whether to compute and store the gradient at the end of the
-      linesearch. Since the function is called to compute the value to accept
-      the learning rate, we can also access the gradient along the way. By doing
-      that, we can directly reuse the value and the gradient computed at the end
-      of the linesearch for the next iteration using
-      :func:`optax.value_and_grad_from_state`. See the example above.
 
-  Returns:
-    A :class:`GradientTransformationExtraArgs`, where the ``update`` function
-    takes the following additional keyword arguments:
+  .. warning::
+    The sufficient decrease criterion might be impossible to satisfy for some
+    update directions. To guarantee a non-trivial solution for the sufficient
+    decrease criterion, a descent direction for updates (:math:`u`) is required.
+    An update (:math:`u`) is considered a descent direction if the derivative of
+    :math:`f(w + \eta u)` at :math:`\eta = 0`
+    (i.e.,  :math:`\langle u, \nabla f(w)\rangle`) is negative.  This condition
+    is automatically satisfied when using :func:`optax.sgd` (without momentum),
+    but may not hold true for other optimizers like :func:`optax.adam`.
 
-    * ``value``: value of the function at the current params.
-    * ``grad``: gradient of the function at the current params.
-    * ``value_fn``: function returning the value of the function we seek to
-      optimize.
-    * ``**extra_args``: additional keyword arguments, if the function needs
-      additional arguments such as input data, they should be put there (
-      see example in this docstrihng).
+
+    More generally, when chained with other transforms as
+    ``optax.chain(opt_1, ..., opt_k,
+    scale_by_backtraking_linesearch(max_backtracking_steps=...),
+    opt_kplusone, ..., opt_n)``, the updates returned by chaining
+    ``opt_1, ..., opt_k`` must be a descent direction. However, any transform
+    after the backtracking line-search doesn't necessarily need to satisfy the
+    descent direction property (one could for example use momentum).
+
+  .. seealso:: :func:`optax.value_and_grad_from_state` to make this method
+    more efficient for non-stochastic objectives.
+
+  .. versionadded:: 0.2.0
   """
 
   def init_fn(params: base.Params) -> ScaleByBacktrackingLinesearchState:
@@ -236,14 +255,25 @@ def scale_by_backtracking_linesearch(
         learning_rate=jnp.array(1.0),
         value=jnp.array(jnp.inf),
         grad=grad,
+        info=BacktrackingLinesearchInfo(
+            num_linesearch_steps=0,
+            decrease_error=jnp.array(jnp.inf),
+        ),
     )
 
-  def _check_criterion(learning_rate, slope, value, new_value):
-    violation = (
-        new_value - (1 + rtol) * value - learning_rate * slope_rtol * slope
+  def _compute_decrease_error(
+      stepsize: chex.Numeric,
+      slope: chex.Numeric,
+      value: chex.Numeric,
+      new_value: chex.Numeric,
+  ) -> chex.Numeric:
+    decrease_error = (
+        new_value - (1.0 + rtol) * value - stepsize * slope_rtol * slope
     )
-    violation = jnp.where(jnp.isnan(violation), jnp.inf, violation)
-    return violation <= atol
+    decrease_error = jnp.where(
+        jnp.isnan(decrease_error), jnp.inf, decrease_error
+    )
+    return jnp.maximum(decrease_error, 0.0)
 
   def update_fn(
       updates: base.Updates,
@@ -257,13 +287,6 @@ def scale_by_backtracking_linesearch(
   ) -> tuple[base.Updates, ScaleByBacktrackingLinesearchState]:
     """Compute scaled updates guaranteeing decrease of current objective.
 
-    .. warning:: The objective to minimize, ``value_fn``, can take more than
-        one input, but must return a single scalar (float or jax.Array of
-        dimension one). If the function requires more than one input, the
-        additional inputs need to be fed to the update, see the example in the
-        docstring of the transform. The function value_fn needs to be amenable
-        to differentiation in JAX.
-
     Args:
       updates: current updates.
       state: current state.
@@ -279,6 +302,13 @@ def scale_by_backtracking_linesearch(
     Returns:
       updates: updates for the params (new_params = params + updates).
       state: updated state.
+
+    .. warning:: The objective to minimize, ``value_fn``, can take more than
+        one input, but must return a single scalar (float or jax.Array of
+        dimension one). If the function requires more than one input, the
+        additional inputs need to be fed to the update, see the example in the
+        docstring of the transform. The function value_fn needs to be amenable
+        to differentiation in JAX.
     """
     # Fetch arguments to be fed to value_fn from the extra_args
     (fn_kwargs,), remaining_kwargs = utils._extract_fns_kwargs(  # pylint: disable=protected-access
@@ -292,16 +322,16 @@ def scale_by_backtracking_linesearch(
     slope = otu.tree_vdot(updates, grad)
 
     def cond_fn(
-        search_state: BacktrackingSearchState,
-    ) -> Union[int, jax._src.basearray.Array]:
+        search_state: BacktrackingLineSearchState,
+    ):
       """Whether to stop the line-search inner loop."""
-      accepted = search_state.accepted
+      decrease_error = search_state.decrease_error
       iter_num = search_state.iter_num
-      return (~accepted) & (iter_num <= max_backtracking_steps)
+      return (~(decrease_error <= atol)) & (iter_num <= max_backtracking_steps)
 
     def body_fn(
-        search_state: BacktrackingSearchState,
-    ) -> BacktrackingSearchState:
+        search_state: BacktrackingLineSearchState,
+    ) -> BacktrackingLineSearchState:
       """Line-search inner loop step."""
       learning_rate = search_state.learning_rate
       new_grad = search_state.new_grad
@@ -319,11 +349,13 @@ def scale_by_backtracking_linesearch(
         # compute the gradient by transposing the jvp.
         new_value, jvp_value_fn = jax.linearize(value_fn_, new_params)
 
-        accepted = _check_criterion(learning_rate, slope, value, new_value)
+        decrease_error = _compute_decrease_error(
+            learning_rate, slope, value, new_value
+        )
         # If the line-search ends, we get the gradient for the new round of
         # line-search.
         new_grad = jax.lax.cond(
-            accepted | (iter_num == max_backtracking_steps),
+            (decrease_error <= atol) | (iter_num == max_backtracking_steps),
             lambda p: jax.linear_transpose(jvp_value_fn, p)(1.0)[0],
             lambda *_: new_grad,
             new_params,
@@ -331,12 +363,14 @@ def scale_by_backtracking_linesearch(
       else:
         # Here we just compute the value and leave the gradient as is
         new_value = value_fn_(new_params)
-        accepted = _check_criterion(learning_rate, slope, value, new_value)
-      search_state = BacktrackingSearchState(
+        decrease_error = _compute_decrease_error(
+            learning_rate, slope, value, new_value
+        )
+      search_state = BacktrackingLineSearchState(
           learning_rate=learning_rate,
           new_value=new_value,
           new_grad=new_grad,
-          accepted=accepted,
+          decrease_error=decrease_error,
           iter_num=iter_num + 1,
       )
       return search_state
@@ -346,12 +380,11 @@ def scale_by_backtracking_linesearch(
     learning_rate = jnp.minimum(
         increase_factor * state.learning_rate, max_learning_rate
     )
-
-    search_state = BacktrackingSearchState(
+    search_state = BacktrackingLineSearchState(
         learning_rate=learning_rate,
         new_value=value,
         new_grad=otu.tree_zeros_like(params),
-        accepted=False,
+        decrease_error=jnp.array(jnp.inf),
         iter_num=0,
     )
     search_state = jax.lax.while_loop(cond_fn, body_fn, search_state)
@@ -360,15 +393,43 @@ def scale_by_backtracking_linesearch(
     # otu.tree_zeros_like(params))
     new_grad = search_state.new_grad if store_grad else None
     new_value = search_state.new_value
-    new_learning_rate = search_state.learning_rate
+    # If the decrease error is infinite, we avoid making any step (which would
+    # result in nan or infinite values): we set the learning rate to 0.
+    new_learning_rate = jnp.where(
+        jnp.isinf(search_state.decrease_error), 0., search_state.learning_rate
+    )
 
+    if verbose:
+      # We print information only if the linesearch failed.
+      _cond_print(
+          search_state.decrease_error > atol,
+          "INFO: optax.scale_by_backtracking_linesearch:\n"
+          "Backtracking linesearch failed to find a stepsize ensuring sufficent"
+          " decrease.\n"
+          "Value at current params: {value},\n"
+          "Slope along update direction: {slope}\n"
+          "Stepsize: {stepsize}\n"
+          "Decrease Error: {decrease_error}",
+          stepsize=search_state.learning_rate,
+          decrease_error=search_state.decrease_error,
+          value=value,
+          slope=slope,
+      )
+      _cond_print(
+          jnp.isinf(search_state.decrease_error),
+          "Using a stepsize of 0 to avoid infinite or nan values.",
+      )
     # At the end, we just scale the updates with the learning rate found.
     new_updates = otu.tree_scalar_mul(new_learning_rate, updates)
-
+    info = BacktrackingLinesearchInfo(
+        num_linesearch_steps=search_state.iter_num,
+        decrease_error=search_state.decrease_error,
+    )
     new_state = ScaleByBacktrackingLinesearchState(
         learning_rate=new_learning_rate,
         value=new_value,
         grad=new_grad,
+        info=info
     )
     return new_updates, new_state
 
@@ -379,7 +440,7 @@ def _cond_print(condition, message, **kwargs):
   """Prints message if condition is true."""
   jax.lax.cond(
       condition,
-      lambda _: jax.debug.print(message, **kwargs),
+      lambda _: jax.debug.print(message, **kwargs, ordered=True),
       lambda _: None,
       None,
   )
@@ -451,6 +512,8 @@ def _quadmin(a, fa, fpa, b, fb):
   B = (fb - D - C * db) / (db**2)
   xmin = a - C / (2.0 * B)
   return xmin
+
+
 # pylint: enable=invalid-name
 
 
@@ -539,34 +602,26 @@ def zoom_linesearch(
     and criteria. It iteratively narrows the interval until a satisfactory step
     size is found.
 
-  References:
-    Algorithms 3.5 3.6 of Nocedal and Wright, `Numerical Optimization
-    <https://doi.org/10.1007/978-0-387-40065-5>`_, 1999
-
-    Hager and Zhang `Algorithm 851: CG_DESCENT, a Conjugate Gradient Method
-    with Guaranteed Descent
-    <https://doi.org/10.1145/1132973.1132979>`_, 2006
-
   Args:
     max_linesearch_steps: maximum number of linesearch iterations.
-    max_stepsize: maximal admissible learning rate. Can be set to ``None``
-      for no upper bound. An inappropriate value may prevent the linesearch to
-      find a learning rate satisfying the small curvature criterion, since the
-      latter may require sufficiently large stepsizes.
+    max_stepsize: maximal admissible learning rate. Can be set to ``None`` for
+      no upper bound. An inappropriate value may prevent the linesearch to find
+      a learning rate satisfying the small curvature criterion, since the latter
+      may require sufficiently large stepsizes.
     tol: tolerance on the criterions.
     increase_factor: increasing factor to augment the learning rate when
       searching for an initial valid interval (1st phase above).
-    slope_rtol: relative tolerance for the slope in the sufficient
-      decrease criterion, see :func:`optax.scale_by_zoom_linesearch`.
+    slope_rtol: relative tolerance for the slope in the sufficient decrease
+      criterion, see :func:`optax.scale_by_zoom_linesearch`.
     curv_rtol: relative tolerance for the curvature in the small curvature
       criterion, see :func:`optax.scale_by_zoom_linesearch`.
-    approx_dec_rtol: relative tolerance for the initial value in the
-      approximate sufficient decrease criterion. Can be set to ``None`` to use
-      only the Armijo-Goldstein decrease criterion, see
+    approx_dec_rtol: relative tolerance for the initial value in the approximate
+      sufficient decrease criterion. Can be set to ``None`` to use only the
+      Armijo-Goldstein decrease criterion, see
       :func:`optax.scale_by_zoom_linesearch`.
     interval_threshold: if the size of the interval searched is below this
-      threshold and a sufficient decrease for some stepsize has been found,
-      then the linesearch selects the stepsize and ends.
+      threshold and a sufficient decrease for some stepsize has been found, then
+      the linesearch selects the stepsize and ends.
     verbose: whether to print debugging information if the linesearch fails.
 
   Returns:
@@ -586,6 +641,14 @@ def zoom_linesearch(
       additional data for example)
     * ``cond_step_fn(state) -> bool`` returns a boolean indicating whether the
       linesearch iterations should continue (``True``) or not (``False``).
+
+  References:
+    Algorithms 3.5 3.6 of Nocedal and Wright, `Numerical Optimization
+    <https://doi.org/10.1007/978-0-387-40065-5>`_, 1999
+
+    Hager and Zhang `Algorithm 851: CG_DESCENT, a Conjugate Gradient Method
+    with Guaranteed Descent
+    <https://doi.org/10.1145/1132973.1132979>`_, 2006
   """
 
   def _value_and_slope_on_line(
@@ -638,7 +701,7 @@ def zoom_linesearch(
     slope_step = otu.tree_vdot(grad_step, updates)
     return step, value_step, grad_step, slope_step
 
-  def _decrease_error(
+  def _compute_decrease_error(
       stepsize: chex.Numeric,
       value_step: chex.Numeric,
       slope_step: chex.Numeric,
@@ -681,7 +744,7 @@ def zoom_linesearch(
     )
     return decrease_error
 
-  def _curvature_error(
+  def _compute_curvature_error(
       slope_step: chex.Numeric, slope_init: chex.Numeric
   ) -> chex.Numeric:
     """Compute curvature error."""
@@ -707,12 +770,33 @@ def zoom_linesearch(
         [state.stepsize, state.value, state.grad],
     )
     if verbose:
-      too_small_int = jnp.abs(state.low - state.high) <= interval_threshold
-      _cond_print(too_small_int, FLAG_INTERVAL_TOO_SMALL)
+      jax.debug.print(
+          "INFO: optax.scale_by_zoom_linesearch:\n"
+          "Value at current params: {value_init}\n"
+          "Slope along update direction: {slope_init}\n"
+          "Stepsize reached: {stepsize}\n"
+          "Decrease Error: {decrease_error}\n"
+          "Curvature Error: {curvature_error}",
+          value_init=state.value_init,
+          slope_init=state.slope_init,
+          stepsize=state.stepsize,
+          decrease_error=state.decrease_error,
+          curvature_error=state.curvature_error,
+          ordered=True,
+      )
+      interval_length = jnp.abs(state.low - state.high)
+      too_small_int = interval_length <= interval_threshold
+      _cond_print(
+          too_small_int,
+          FLAG_INTERVAL_TOO_SMALL + " Interval length: {interval_length}.",
+          interval_length=interval_length,
+      )
       jax.lax.cond(
           state.safe_stepsize > 0.0,
-          lambda *_: jax.debug.print(
-              FLAG_CURVATURE_COND_NOT_SATSIFIED
+          lambda _: jax.debug.print(
+              FLAG_CURVATURE_COND_NOT_SATISFIED
+              + " Stepsize ensuring sufficient decrease: {safe_stepsize}.",
+              safe_stepsize=state.safe_stepsize,
           ),
           _failure_diagnostic,
           state,
@@ -760,10 +844,10 @@ def zoom_linesearch(
         value_and_grad_fn, params, new_stepsize, updates, fn_kwargs
     )
 
-    decrease_error = _decrease_error(
+    decrease_error = _compute_decrease_error(
         new_stepsize, new_value_step, new_slope_step, value_init, slope_init
     )
-    curvature_error = _curvature_error(new_slope_step, slope_init)
+    curvature_error = _compute_curvature_error(new_slope_step, slope_init)
     new_error = jnp.maximum(decrease_error, curvature_error)
 
     # If the new point satisfies at least the decrease error we keep it
@@ -823,14 +907,25 @@ def zoom_linesearch(
     if verbose:
       _cond_print(
           (max_stepsize_reached & ~interval_found),
-          FLAG_INTERVAL_NOT_FOUND
+          "INFO: optax.scale_by_zoom_linesearch:\n"
+          "Value at current params: {value_init}\n"
+          "Slope along update direction: {slope_init}\n"
+          "Stepsize reached: {stepsize}\n"
+          "Decrease Error: {decrease_error}\n"
+          "Curvature Error: {curvature_error}"
+          + FLAG_INTERVAL_NOT_FOUND
           + "\n"
-          + FLAG_CURVATURE_COND_NOT_SATSIFIED,
+          + FLAG_CURVATURE_COND_NOT_SATISFIED,
+          value_init=value_init,
+          slope_init=slope_init,
+          stepsize=new_stepsize,
+          decrease_error=decrease_error,
+          curvature_error=curvature_error,
       )
     failed = (iter_num + 1 >= max_linesearch_steps) & (~done)
 
     new_state = ZoomLinesearchState(
-        count=numerics.safe_int32_increment(iter_num),
+        count=numerics.safe_increment(iter_num),
         #
         params=params,
         updates=updates,
@@ -871,7 +966,7 @@ def zoom_linesearch(
       state: ZoomLinesearchState,
       value_and_grad_fn: Callable[..., tuple[chex.Numeric, base.Updates]],
       fn_kwargs: dict[str, Any],
-    ) -> ZoomLinesearchState:
+  ) -> ZoomLinesearchState:
     """Zoom procedure, Algorithm 3.6 of [Nocedal and Wright, 1999]."""
 
     iter_num = state.count
@@ -929,16 +1024,14 @@ def zoom_linesearch(
     middle = jnp.where(use_bisection, middle_bisection, middle)
 
     # Check if new point is good
-    _, value_middle, grad_middle, slope_middle = (
-        _value_and_slope_on_line(
-            value_and_grad_fn, params, middle, updates, fn_kwargs
-        )
+    _, value_middle, grad_middle, slope_middle = _value_and_slope_on_line(
+        value_and_grad_fn, params, middle, updates, fn_kwargs
     )
 
-    decrease_error = _decrease_error(
+    decrease_error = _compute_decrease_error(
         middle, value_middle, slope_middle, value_init, slope_init
     )
-    curvature_error = _curvature_error(slope_middle, slope_init)
+    curvature_error = _compute_curvature_error(slope_middle, slope_init)
     new_error = jnp.maximum(decrease_error, curvature_error)
 
     # If the new point satisfies at least the decrease error we keep it in case
@@ -1002,7 +1095,7 @@ def zoom_linesearch(
     )
     failed = presumably_failed & ~done
     new_state = ZoomLinesearchState(
-        count=numerics.safe_int32_increment(iter_num),
+        count=numerics.safe_increment(iter_num),
         #
         params=params,
         updates=updates,
@@ -1041,20 +1134,8 @@ def zoom_linesearch(
 
   def _failure_diagnostic(state: ZoomLinesearchState) -> None:
     """Prints failure diagnostics."""
-    stepsize = state.stepsize
     jax.debug.print(FLAG_NO_STEPSIZE_FOUND)
-    jax.debug.print(
-        "INFO: optax.zoom_linesearch: "
-        "Iter: {} "
-        "Stepsize: {} "
-        "Decrease Error: {} "
-        "Curvature Error: {} ",
-        state.count,
-        stepsize,
-        state.decrease_error,
-        state.curvature_error,
-        ordered=True
-    )
+    stepsize = state.stepsize
 
     slope_init = state.slope_init
     is_descent_dir = slope_init < 0.0
@@ -1066,15 +1147,13 @@ def zoom_linesearch(
     )
     _cond_print(
         is_descent_dir,
-        WARNING_PREAMBLE
-        + "Consider augmenting the maximal number of linesearch iterations.",
+        "Consider augmenting the maximal number of linesearch iterations.",
     )
     eps = jnp.finfo(jnp.float32).eps
     below_eps = stepsize < eps
     _cond_print(
         below_eps & is_descent_dir,
-        WARNING_PREAMBLE
-        + "Computed stepsize (={stepsize}) "
+        "Computed stepsize (={stepsize}) "
         "is below machine precision (={eps}), "
         "consider passing to higher precision like x64, using "
         "jax.config.update('jax_enable_x64', True).",
@@ -1085,8 +1164,7 @@ def zoom_linesearch(
     high_slope = abs_slope_init > 1e16
     _cond_print(
         high_slope & is_descent_dir,
-        WARNING_PREAMBLE
-        + "Very large absolute slope at stepsize=0. "
+        "Very large absolute slope at stepsize=0. "
         "(|slope|={abs_slope_init}). "
         "The objective is badly conditioned. "
         "Consider reparameterizing objective (e.g., normalizing parameters) "
@@ -1097,14 +1175,12 @@ def zoom_linesearch(
     outside_domain = jnp.isinf(state.decrease_error)
     _cond_print(
         outside_domain,
-        WARNING_PREAMBLE
-        + "Cannot even make a step without getting Inf or Nan. "
+        "Cannot even make a step without getting Inf or Nan. "
         + "The linesearch won't make a step and the optimizer is stuck.",
     )
     _cond_print(
         ~outside_domain,
-        WARNING_PREAMBLE
-        + "Making an unsafe step, not decreasing enough the objective. "
+        "Making an unsafe step, not decreasing enough the objective. "
         "Convergence of the solver is compromised as it does not reduce"
         " values.",
     )
@@ -1115,9 +1191,20 @@ def zoom_linesearch(
       *,
       value: chex.Numeric,
       grad: base.Updates,
-      stepsize_guess: chex.Numeric = 1.0,
+      prev_stepsize: chex.Numeric = 1.0,
+      initial_guess_strategy: str = "one",
   ) -> ZoomLinesearchState:
     """Initializes the linesearch state."""
+
+    if initial_guess_strategy == "one":
+      stepsize_guess = jnp.asarray(1.0)
+    elif initial_guess_strategy == "keep":
+      stepsize_guess = prev_stepsize
+    else:
+      raise ValueError(
+          f"Unknown initial guess strategy: {initial_guess_strategy}"
+      )
+
     slope = otu.tree_vdot(updates, grad)
     return ZoomLinesearchState(
         count=jnp.asarray(0, dtype=jnp.int32),
@@ -1178,10 +1265,7 @@ def zoom_linesearch(
         state,
     )
     new_state = jax.lax.cond(
-        new_state.failed,
-        _try_safe_step,
-        lambda x: x,
-        new_state
+        new_state.failed, _try_safe_step, lambda x: x, new_state
     )
     return new_state
 
@@ -1212,6 +1296,7 @@ class ZoomLinesearchInfo(NamedTuple):
       linesearch failed to find a stepsize that ensures a small curvature. A
       null value indicates it succeeded in finding such a stepsize.
   """
+
   num_linesearch_steps: Union[int, chex.Numeric]
   decrease_error: Union[float, chex.Numeric]
   curvature_error: Union[float, chex.Numeric]
@@ -1226,11 +1311,11 @@ class ScaleByZoomLinesearchState(NamedTuple):
     value: value of the objective computed at the end of a round of line-search.
       Can be reused using :func:`optax.value_and_grad_from_state`.
     grad: gradient of the objective computed at the end of a round of
-      line-search. Can be reused using
-      :func:`optax.value_and_grad_from_state`.
+      line-search. Can be reused using :func:`optax.value_and_grad_from_state`.
     info: Additional information on the status of the linesearch see
       :class:`otpax.ZoomLinesearchInfo`.
   """
+
   learning_rate: chex.Numeric
   value: chex.Numeric
   grad: base.Updates
@@ -1246,8 +1331,9 @@ def scale_by_zoom_linesearch(
     curv_rtol: float = 0.9,
     approx_dec_rtol: Optional[float] = 1e-6,
     stepsize_precision: float = 1e-5,
+    initial_guess_strategy: str = "keep",
     verbose: bool = False,
-    ) -> base.GradientTransformationExtraArgs:
+) -> base.GradientTransformationExtraArgs:
   r"""Linesearch ensuring sufficient decrease and small curvature.
 
   This algorithm searches for a learning rate, a.k.a. stepsize, that satisfies
@@ -1299,12 +1385,46 @@ def scale_by_zoom_linesearch(
   differences up to :math:`\sqrt{\varepsilon_{machine}}` while the approximate
   sufficient decrease criterion can capture differences up to
   :math:`\varepsilon_{machine}` (see [Hager and Zhang, 2006]).
-  Note that this add-on is not part of the original implementation of 
+  Note that this add-on is not part of the original implementation of
   [Nocedal and Wright, 1999] and can be removed by
   setting ``approx_dec_rtol`` to ``None``.
 
-  .. seealso:: :func:`optax.value_and_grad_from_state` to make this method
-    more efficient for non-stochastic objectives.
+  Args:
+    max_linesearch_steps: maximum number of linesearch iterations.
+    max_learning_rate: maximum admissible learning rate. Can be set to ``None``
+      for no upper bound. A non ``None`` value may prevent the linesearch to
+      find a learning rate satisfying the small curvature criterion, since the
+      latter may require sufficiently large stepsizes.
+    tol: tolerance on the criterions.
+    increase_factor: increasing factor to augment the learning rate when
+      searching for a valid interval containing a learning rate satisfying both
+      criterions.
+    slope_rtol: relative tolerance for the slope in the sufficient decrease
+      criterion.
+    curv_rtol: relative tolerance for the curvature in the small curvature
+      criterion.
+    approx_dec_rtol: relative tolerance for the initial value in the approximate
+      sufficient decrease criterion. Can be set to ``None`` to use only the
+      original Armijo-Goldstein decrease criterion.
+    stepsize_precision: precision in the search of a stepsize satisfying both
+      conditions. The algorithm proceeds with a bisection that refines an
+      interval containing a stepsize satisfying both conditions. If that
+      interval is reduced below ``stepsize_precision`` and a stepsize satisfying
+      a sufficient decrease has been found, the algorithm selects that stepsize
+      even if the curvature condition is not satisfied.
+    initial_guess_strategy: initial guess for the learning rate used to start
+      the linesearch. Can be either ``one`` or ``keep``. If ``one``, the initial
+      guess is set to 1. If ``keep``, the initial guess is set to the learning
+      rate of the previous step. We recommend to use ``keep`` if this linesearch
+      is used in combination with SGD. We recommend to use ``one`` if this
+      linesearch is used in combination with Newton methods or quasi-Newton
+      methods such as L-BFGS.
+    verbose: whether to print additional debugging information in case the
+      linesearch fails.
+
+  Returns:
+    A :class:`optax.GradientTransformationExtraArgs` object consisting in
+    an init and an update function.
 
   Examples:
     An example on using the zoom line-search with SGD::
@@ -1383,35 +1503,16 @@ def scale_by_zoom_linesearch(
     with Guaranteed Descent
     <https://doi.org/10.1145/1132973.1132979>`_, 2006
 
-  Args:
-    max_linesearch_steps: maximum number of linesearch iterations.
-    max_learning_rate: maximum admissible learning rate. Can be set to ``None``
-      for no upper bound. A non ``None`` value may prevent the linesearch to
-      find a learning rate satisfying the small curvature criterion, since the
-      latter may require sufficiently large stepsizes.
-    tol: tolerance on the criterions.
-    increase_factor: increasing factor to augment the learning rate when
-      searching for a valid interval containing a learning rate satisfying both
-      criterions.
-    slope_rtol: relative tolerance for the slope in the sufficient decrease
-      criterion.
-    curv_rtol: relative tolerance for the curvature in the small curvature
-      criterion.
-    approx_dec_rtol: relative tolerance for the initial value in the
-      approximate sufficient decrease criterion. Can be set to ``None`` to use
-      only the original Armijo-Goldstein decrease criterion.
-    stepsize_precision: precision in the search of a stepsize satisfying both
-      conditions. The algorithm proceeds with a bisection that refines an
-      interval containing a stepsize satisfying both conditions. If that
-      interval is reduced below ``stepsize_precision`` and a stepsize satisfying
-      a sufficient decrease has been found, the algorithm selects that stepsize
-      even if the curvature condition is not satisfied.
-    verbose: whether to print additional debugging information in case the
-      linesearch fails.
+  .. note::
+    The curvature criterion can be avoided by setting by setting
+    ``curv_rtol=jnp.inf``. The resulting algorithm will amount to a
+    backtracking linesearch where a point satisfying sufficient decrease is 
+    searched by minimizing a quadratic or cubic approximation of the objective.
+    This can be sufficient in practice and avoids having the linesearch spend 
+    many iterations trying to satisfy the small curvature criterion.
 
-  Returns:
-    A :class:`optax.GradientTransformationExtraArgs` object consisting in
-    an init and an update function.
+  .. seealso:: :func:`optax.value_and_grad_from_state` to make this method
+    more efficient for non-stochastic objectives.
   """
 
   # Instantiates the linesearch with the given arguments.
@@ -1452,13 +1553,6 @@ def scale_by_zoom_linesearch(
   ) -> tuple[base.Updates, ScaleByZoomLinesearchState]:
     """Scales updates using the zoom linesearch.
 
-    .. warning:: The objective to minimize, ``value_fn``, can take more than
-        one input, but must return a single scalar (``float`` or scalar 
-        ``jax.Array``). If the function requires more than one input, the
-        additional inputs need to be fed to the update, see the example in the
-        docstring of the transform. The function value_fn needs to be amenable
-        to differentiation in JAX.
-
     Args:
       updates: current updates.
       state: current state.
@@ -1473,6 +1567,13 @@ def scale_by_zoom_linesearch(
     Returns:
       updates: updates for the params (new_params = params + updates).
       state: updated state.
+
+    .. warning:: The objective to minimize, ``value_fn``, can take more than
+        one input, but must return a single scalar (``float`` or scalar
+        ``jax.Array``). If the function requires more than one input, the
+        additional inputs need to be fed to the update, see the example in the
+        docstring of the transform. The function value_fn needs to be amenable
+        to differentiation in JAX.
     """
     # Fetch arguments to be fed to value_fn from the extra_args
     (fn_kwargs,), remaining_kwargs = utils._extract_fns_kwargs(  # pylint: disable=protected-access
@@ -1481,13 +1582,13 @@ def scale_by_zoom_linesearch(
     del remaining_kwargs
     value_and_grad_fn = jax.value_and_grad(value_fn)
 
-    stepsize_guess = state.learning_rate
     init_state = init_ls(
         updates,
         params,
         value=value,
         grad=grad,
-        stepsize_guess=stepsize_guess,
+        prev_stepsize=state.learning_rate,
+        initial_guess_strategy=initial_guess_strategy,
     )
 
     final_state = jax.lax.while_loop(
@@ -1515,27 +1616,21 @@ def scale_by_zoom_linesearch(
 
 
 # Flags to print errors, used for debugging, tested
-WARNING_PREAMBLE = "WARNING: optax.zoom_linesearch: "
 FLAG_INTERVAL_NOT_FOUND = (
-    WARNING_PREAMBLE
-    + "No interval satisfying curvature condition."
+    "No interval satisfying curvature condition. "
     "Consider increasing maximal possible stepsize of the linesearch."
 )
 FLAG_INTERVAL_TOO_SMALL = (
-    WARNING_PREAMBLE
-    + "Length of searched interval has been reduced below threshold."
+    "Length of searched interval has been reduced below threshold."
 )
-FLAG_CURVATURE_COND_NOT_SATSIFIED = (
-    WARNING_PREAMBLE
-    + "Returning stepsize with sufficient decrease "
+FLAG_CURVATURE_COND_NOT_SATISFIED = (
+    "Returning stepsize with sufficient decrease "
     "but curvature condition not satisfied."
 )
 FLAG_NO_STEPSIZE_FOUND = (
-    WARNING_PREAMBLE
-    + "Linesearch failed, no stepsize satisfying sufficient decrease found."
+    "Linesearch failed, no stepsize satisfying sufficient decrease found."
 )
 FLAG_NOT_A_DESCENT_DIRECTION = (
-    WARNING_PREAMBLE
-    + "The linesearch failed because the provided direction "
+    "The linesearch failed because the provided direction "
     "is not a descent direction. "
 )
