@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Tests for optax.losses._classification."""
+"""Tests for losses in `optax.losses._classification.py`."""
 
 import functools
 
@@ -23,7 +23,6 @@ import jax
 import jax.numpy as jnp
 import jax.test_util as jaxtest
 import numpy as np
-
 from optax import projections
 from optax.losses import _classification
 
@@ -82,6 +81,30 @@ class SoftmaxCrossEntropyTest(parameterized.TestCase):
         order=1,
     )
 
+  @parameterized.parameters(dict(size=5), dict(size=10))
+  def test_mask(self, size):
+    preds = np.random.normal(size=size)
+    targets = np.random.dirichlet(np.ones(size))
+    mask = np.random.randint(2, size=size, dtype=bool)
+    x = _classification.softmax_cross_entropy(preds[mask], targets[mask])
+    y = _classification.softmax_cross_entropy(preds, targets, where=mask)
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.random.dirichlet(np.ones(shape[-1]), size=shape[:-1])
+    x = _classification.softmax_cross_entropy(preds, targets, axis=axis)
+    y = _classification.softmax_cross_entropy(
+        np.moveaxis(preds, axis, -1),
+        np.moveaxis(targets, axis, -1),
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 class SafeSoftmaxCrossEntropyTest(parameterized.TestCase):
 
@@ -206,6 +229,24 @@ class SoftmaxCrossEntropyWithIntegerLabelsTest(parameterized.TestCase):
         order=1,
     )
 
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.random.randint(
+        shape[axis], size=shape[:axis] + shape[axis + 1 :]
+    )
+    f = _classification.softmax_cross_entropy_with_integer_labels
+    x = f(preds, targets, axis=axis)
+    y = f(
+        np.moveaxis(preds, axis, -1),
+        targets,
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 class SigmoidCrossEntropyTest(parameterized.TestCase):
 
@@ -353,6 +394,30 @@ class PolyLossTest(parameterized.TestCase):
         atol=1e-4,
     )
 
+  @parameterized.parameters(dict(size=5), dict(size=10))
+  def test_mask(self, size):
+    preds = np.random.normal(size=size)
+    targets = np.random.dirichlet(np.ones(size))
+    mask = np.random.randint(2, size=size, dtype=bool)
+    x = _classification.poly_loss_cross_entropy(preds[mask], targets[mask])
+    y = _classification.poly_loss_cross_entropy(preds, targets, where=mask)
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.random.dirichlet(np.ones(shape[-1]), size=shape[:-1])
+    x = _classification.poly_loss_cross_entropy(preds, targets, axis=axis)
+    y = _classification.poly_loss_cross_entropy(
+        np.moveaxis(preds, axis, -1),
+        np.moveaxis(targets, axis, -1),
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 class HingeTest(parameterized.TestCase):
 
@@ -452,9 +517,7 @@ class SparsemaxTest(parameterized.TestCase):
   def test_multi_class_zero_loss(self):
     # Check that putting large scores on the correct class gives a zero loss.
     labels = jnp.array([1, 0, 2])
-    scores = jnp.array([[0.0, 1e5, 0.0],
-                        [1e5, 0.0, 0.0],
-                        [0.0, 0.0, 1e5]])
+    scores = jnp.array([[0.0, 1e5, 0.0], [1e5, 0.0, 0.0], [0.0, 0.0, 1e5]])
     losses = _classification.multiclass_sparsemax_loss(scores, labels)
     np.testing.assert_allclose(losses, np.array([0.0, 0.0, 0.0]), atol=1e-4)
 
@@ -464,9 +527,7 @@ class SparsemaxTest(parameterized.TestCase):
       return jnp.mean(_classification.multiclass_sparsemax_loss(scores, labels))
 
     labels = jnp.array([1, 0, 2])
-    scores = jnp.array([[0.0, 1e5, 0.0],
-                        [1e5, 0.0, 0.0],
-                        [0.0, 0.0, 1e5]])
+    scores = jnp.array([[0.0, 1e5, 0.0], [1e5, 0.0, 0.0], [0.0, 0.0, 1e5]])
     grad = jax.grad(loss_mean)(scores, labels)
     projection_vmap = jax.vmap(projections.projection_simplex)
     grad_expected = projection_vmap(scores) - jax.nn.one_hot(labels, 3)
@@ -508,6 +569,30 @@ class ConvexKLDivergenceTest(parameterized.TestCase):
         atol=1e-4,
     )
 
+  @parameterized.parameters(dict(size=5), dict(size=10))
+  def test_mask(self, size):
+    preds = np.random.normal(size=size)
+    targets = np.random.dirichlet(np.ones(size))
+    mask = np.random.randint(2, size=size, dtype=bool)
+    x = _classification.convex_kl_divergence(preds[mask], targets[mask])
+    y = _classification.convex_kl_divergence(preds, targets, where=mask)
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.random.dirichlet(np.ones(shape[-1]), size=shape[:-1])
+    x = _classification.convex_kl_divergence(preds, targets, axis=axis)
+    y = _classification.convex_kl_divergence(
+        np.moveaxis(preds, axis, -1),
+        np.moveaxis(targets, axis, -1),
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 class PerceptronTest(parameterized.TestCase):
 
@@ -590,6 +675,30 @@ class KLDivergenceTest(parameterized.TestCase):
         atol=1e-4,
     )
 
+  @parameterized.parameters(dict(size=5), dict(size=10))
+  def test_mask(self, size):
+    preds = np.random.normal(size=size)
+    targets = np.random.dirichlet(np.ones(size))
+    mask = np.random.randint(2, size=size, dtype=bool)
+    x = _classification.kl_divergence(preds[mask], targets[mask])
+    y = _classification.kl_divergence(preds, targets, where=mask)
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.random.dirichlet(np.ones(shape[-1]), size=shape[:-1])
+    x = _classification.kl_divergence(preds, targets, axis=axis)
+    y = _classification.kl_divergence(
+        np.moveaxis(preds, axis, -1),
+        np.moveaxis(targets, axis, -1),
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 class KLDivergenceWithLogTargetsTest(parameterized.TestCase):
 
@@ -626,6 +735,32 @@ class KLDivergenceWithLogTargetsTest(parameterized.TestCase):
         atol=1e-4,
     )
 
+  @parameterized.parameters(dict(size=5), dict(size=10))
+  def test_mask(self, size):
+    preds = np.random.normal(size=size)
+    targets = np.log(np.random.dirichlet(np.ones(size)))
+    mask = np.random.randint(2, size=size, dtype=bool)
+    f = _classification.kl_divergence_with_log_targets
+    x = f(preds[mask], targets[mask])
+    y = f(preds, targets, where=mask)
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
+  @parameterized.parameters(
+      dict(axis=0, shape=[4, 5, 6]),
+      dict(axis=1, shape=[4, 5, 6]),
+      dict(axis=2, shape=[4, 5, 6]),
+  )
+  def test_axis(self, shape, axis):
+    preds = np.random.normal(size=shape)
+    targets = np.log(np.random.dirichlet(np.ones(shape[-1]), size=shape[:-1]))
+    f = _classification.kl_divergence_with_log_targets
+    x = f(preds, targets, axis=axis)
+    y = f(
+        np.moveaxis(preds, axis, -1),
+        np.moveaxis(targets, axis, -1),
+    )
+    np.testing.assert_allclose(x, y, atol=1e-4)
+
 
 def _lengths_to_paddings(lengths: chex.Array, maxlength: int) -> chex.Array:
   indices = jnp.arange(maxlength).reshape((1,) * lengths.ndim + (maxlength,))
@@ -714,7 +849,7 @@ class CTCTest(parameterized.TestCase):
     logprobs = jax.nn.log_softmax(logits)
 
     labels = []
-    for n in range(batch_size):
+    for _ in range(batch_size):
       row = list(range(1, nclasses))
       np.random.shuffle(row)
       labels.append(row[:steps])
