@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Tests for `inject.py`."""
+"""Tests for methods in `inject.py`."""
 
 import functools
 from typing import NamedTuple
@@ -56,7 +56,9 @@ class InjectHyperparamsTest(chex.TestCase):
   def test_updates(self):
     optim = _inject.inject_hyperparams(transform.scale)(  # stateless
         step_size=_schedule.piecewise_constant_schedule(
-            3.0, {1: 5, 7: 2, 12: 1.5}))
+            3.0, {1: 5, 7: 2, 12: 1.5}
+        )
+    )
 
     params = [jnp.zeros([], dtype=jnp.float32)]
     state = self.variant(optim.init)(params)
@@ -65,43 +67,43 @@ class InjectHyperparamsTest(chex.TestCase):
     state = _state_utils.tree_map_params(optim, lambda v: v, state)
 
     update_fn = self.variant(optim.update)
-    expected_step_size = [3.0]*2 + [15.0]*6 + [30.0]*5 + [45.0]*3
+    expected_step_size = [3.0] * 2 + [15.0] * 6 + [30.0] * 5 + [45.0] * 3
 
     grads = [jnp.ones([], dtype=jnp.float32)]
     for i in range(15):
       updates, state = update_fn(grads, state, params=params)
-      np.testing.assert_almost_equal(updates[0], expected_step_size[i+1])
+      np.testing.assert_almost_equal(updates[0], expected_step_size[i + 1])
 
   @chex.all_variants
   def test_hyperparams_state(self):
     optim = _inject.inject_hyperparams(transform.trace)(  # stateful
-        decay=_schedule.piecewise_constant_schedule(
-            0.8, {3: 0.5, 9: 1.25}),
-        nesterov=True)
+        decay=_schedule.piecewise_constant_schedule(0.8, {3: 0.5, 9: 1.25}),
+        nesterov=True,
+    )
 
     params = [jnp.zeros([2, 3]) for _ in range(3)]
     state = self.variant(optim.init)(params)
     update_fn = self.variant(optim.update)
 
-    expected_mom = [0.8]*4 + [0.4]*6 + [0.5]*2
-    grads = jax.tree_util.tree_map(jnp.ones_like, params)
+    expected_mom = [0.8] * 4 + [0.4] * 6 + [0.5] * 2
+    grads = jax.tree.map(jnp.ones_like, params)
     for i in range(12):
-      np.testing.assert_almost_equal(state.hyperparams['decay'],
-                                     expected_mom[i])
+      np.testing.assert_almost_equal(
+          state.hyperparams['decay'], expected_mom[i]
+      )
       _, state = update_fn(grads, state)
 
-    np.testing.assert_almost_equal(state.hyperparams['decay'],
-                                   expected_mom[-1])
+    np.testing.assert_almost_equal(state.hyperparams['decay'], expected_mom[-1])
 
   @chex.all_variants
   def test_constant_hyperparams(self):
-    optim = _inject.inject_hyperparams(transform.scale_by_adam)(b1=0., b2=0.)
+    optim = _inject.inject_hyperparams(transform.scale_by_adam)(b1=0.0, b2=0.0)
 
     params = [jnp.zeros([2, 3]) for _ in range(3)]
     state = self.variant(optim.init)(params)
     update_fn = self.variant(optim.update)
 
-    grads = jax.tree_util.tree_map(jnp.ones_like, params)
+    grads = jax.tree.map(jnp.ones_like, params)
     for _ in range(5):
       updates, state = update_fn(grads, state, params)
       np.testing.assert_almost_equal(state.hyperparams['b1'], 0.0)
@@ -132,13 +134,15 @@ class InjectHyperparamsTest(chex.TestCase):
       return wrappers.masked(transform.scale(-learning_rate), mask)
 
     optim = custom_optim(
-        0.1, functools.partial(jax.tree_util.tree_map, lambda x: x.ndim > 1))
+        0.1, functools.partial(jax.tree.map, lambda x: x.ndim > 1)
+    )
     params = [jnp.ones((1, 2)), jnp.ones(2), jnp.ones((1, 1, 1))]
     grads = params
     state = self.variant(optim.init)(params)
     updates, state = self.variant(optim.update)(grads, state)
-    expected_updates = jax.tree_util.tree_map(
-        lambda x: -0.1 * x if x.ndim > 1 else x, grads)
+    expected_updates = jax.tree.map(
+        lambda x: -0.1 * x if x.ndim > 1 else x, grads
+    )
 
     assert set(state.hyperparams.keys()) == {'learning_rate'}, state.hyperparams
     chex.assert_trees_all_close(updates, expected_updates)
@@ -147,7 +151,8 @@ class InjectHyperparamsTest(chex.TestCase):
   @parameterized.named_parameters(('one_arg', 'b1'), ('two_arg', ['b1', 'b2']))
   def test_numeric_static_args(self, static_args):
     optim = _inject.inject_hyperparams(
-        transform.scale_by_adam, static_args=static_args)(b1=0.9, b2=0.95)
+        transform.scale_by_adam, static_args=static_args
+    )(b1=0.9, b2=0.95)
 
     params = [jnp.ones((1, 2)), jnp.ones(2), jnp.ones((1, 1, 1))]
     grads = params
@@ -163,20 +168,19 @@ class InjectHyperparamsTest(chex.TestCase):
       ('f32hyp bf16param bf16grad', jnp.float32, jnp.bfloat16, jnp.bfloat16),
       ('f32hyp f32param bf16grad', jnp.float32, jnp.float32, jnp.bfloat16),
       ('f32hyp bf16param f32grad', jnp.float32, jnp.bfloat16, jnp.float32),
-      )
-  def test_hyperparam_dtypes(self,
-                             hyperparam_dtype,
-                             param_dtype,
-                             grad_dtype):
+  )
+  def test_hyperparam_dtypes(self, hyperparam_dtype, param_dtype, grad_dtype):
     """Tests that hyperparam dtype override works as desired."""
     optim = _inject.inject_hyperparams(
-        transform.scale_by_adam,
-        hyperparam_dtype=hyperparam_dtype)(b1=0.9, b2=0.95)
+        transform.scale_by_adam, hyperparam_dtype=hyperparam_dtype
+    )(b1=0.9, b2=0.95)
 
-    params = [jnp.ones((1, 2), dtype=param_dtype),
-              jnp.ones(2, dtype=param_dtype),
-              jnp.ones((1, 1, 1), dtype=param_dtype)]
-    grads = jax.tree_util.tree_map(lambda x: x.astype(grad_dtype), params)
+    params = [
+        jnp.ones((1, 2), dtype=param_dtype),
+        jnp.ones(2, dtype=param_dtype),
+        jnp.ones((1, 1, 1), dtype=param_dtype),
+    ]
+    grads = jax.tree.map(lambda x: x.astype(grad_dtype), params)
     state = self.variant(optim.init)(params)
     # Check that the hyperparams are overridden
     self.assertEqual(state.hyperparams['b1'].dtype, hyperparam_dtype)
@@ -206,7 +210,7 @@ class InjectHyperparamsTest(chex.TestCase):
 class StatefulTest(chex.TestCase):
 
   def test_wrap_stateless_schedule(self):
-    my_schedule = _schedule.linear_schedule(1., 1., 10)
+    my_schedule = _schedule.linear_schedule(1.0, 1.0, 10)
     my_wrapped_schedule = _inject.WrappedSchedule(my_schedule)
 
     count = jnp.zeros([], dtype=jnp.int32)
@@ -215,7 +219,8 @@ class StatefulTest(chex.TestCase):
 
     for _ in range(8):
       np.testing.assert_allclose(
-          my_schedule(count), my_wrapped_schedule(state), atol=0.0)
+          my_schedule(count), my_wrapped_schedule(state), atol=0.0
+      )
       count = count + 1
       extra_args = dict(loss=jnp.ones([], dtype=jnp.float32))
       state = my_wrapped_schedule.update(state, **extra_args)
@@ -225,19 +230,23 @@ class StatefulTest(chex.TestCase):
   def test_inject_stateful_hyperparams(self):
     grads = (
         jnp.ones((3,), dtype=jnp.float32),
-        jnp.ones((2,), dtype=jnp.float32),)
+        jnp.ones((2,), dtype=jnp.float32),
+    )
     params = grads
 
     my_stateful_schedule = ExampleStatefulSchedule()
-    tx = _inject.inject_hyperparams(
-        transform.scale)(step_size=my_stateful_schedule)
+    tx = _inject.inject_hyperparams(transform.scale)(
+        step_size=my_stateful_schedule
+    )
     state = self.variant(tx.init)(params)
 
     extra_args = dict(addendum=0.3 * jnp.ones((), dtype=jnp.float32))
     _, state = self.variant(tx.update)(
-        grads, state, params=params, **extra_args)
+        grads, state, params=params, **extra_args
+    )
     _, state = self.variant(tx.update)(
-        grads, state, params=params, **extra_args)
+        grads, state, params=params, **extra_args
+    )
 
     lr = state.hyperparams['step_size']
     total = state.hyperparams_states['step_size']
@@ -245,5 +254,6 @@ class StatefulTest(chex.TestCase):
     np.testing.assert_allclose(lr, extra_args['addendum'], atol=0.0)
     np.testing.assert_allclose(total, 2 * extra_args['addendum'], atol=0.0)
 
+
 if __name__ == '__main__':
   absltest.main()
